
#ifdef WIN32 //if we are under windows...
	//we need to have this include
	#include <windows.h> 
#endif

//include GLUT
#include <GL/glut.h>

//set the macros for the window size
#define SIZEX 500
#define SIZEY 500

//initializing stuff
void init(void)
{
    glDisable( GL_DEPTH_TEST ); //triangles have two sides
	glDisable( GL_CULL_FACE ); //triangles have two sides
}

//this function updates the coordinates system
void onReshape(int w, int h)
{
	//range is the value from which the coordinates system goes, -range to +range
	float range = 1.0f;

	// Prevent a divide by zero
	if(h == 0) h = 1;

	// Set Viewport to window dimensions
    glViewport(0, 0, w, h);

	// Reset coordinate system
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();

	// Establish clipping volume (left, right, bottom, top, near, far)
    if (w <= h) 
		glOrtho (-range, range, -range*h/w, range*h/w, -range, range);
    else 
		glOrtho (-range*w/h, range*w/h, -range, range, -range, range);

	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
}

//process key strokes
void onKey(unsigned char key, int x, int y)
{
    switch (key) 
	{	//example of keyboard input
		case '0': glClearColor(0,0,0,0); break;
		case '1': glClearColor(0.2,0,0,0); break;
		case '2': glClearColor(0,0.2,0,0); break;
		case '3': glClearColor(0,0,0.2,0); break;

		case 27: exit(0); //ESC key
				 break;
	}
}

//Render one frame
void render(void)
{
	//Clear the window and the depth buffer
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

	//Render the triangle
	glBegin(GL_TRIANGLES);
		glColor3f(1.0f, 0.0f, 0.0f ); //change vertex color
		glVertex2d( -0.5f, -0.5f );
		
		glColor3f(0.0f, 1.0f, 0.0f ); //change vertex color
		glVertex2d( 0.5f, -0.5f );
		
		glColor3f(0.0f, 0.0f, 1.0f ); //change vertex color
		glVertex2d( 0.0f, 0.5f );
	glEnd();

	//Swap front and back buffer
	glutSwapBuffers();
}


int main(int argc, char **argv)
{
	//init all OpenGL stuff
    glutInit(&argc, argv); //init GLUT
    glutInitDisplayMode( GLUT_RGB | GLUT_DEPTH | GLUT_DOUBLE ); //init framebuffer properties
    glutInitWindowSize(SIZEX, SIZEY); //init window dimensions
    glutCreateWindow("Framework");	//create window

	//now that we have the window we can set the opengl state
    init(); 

	//set the callbacks
    glutReshapeFunc(onReshape); //when the window shape changes (resizing)
	glutKeyboardFunc(onKey);	  //when a key is pressed or released
    glutDisplayFunc(render);  //render a frame
	glutIdleFunc(render);		  //what to do when nothing happens

	//start the GLUT mainloop (this function will be executed in a loop)
    glutMainLoop();	  

	return 0;
}
